==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/lt_LT.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendorius",
    "Todos" : "Užduotys",
    "Personal" : "Asmeniniai",
    "{actor} created calendar {calendar}" : "{actor} sukūrė kalendorių {calendar}",
    "You created calendar {calendar}" : "Jūs sukūrėte kalendorių {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ištrynė kalendorių {calendar}",
    "You deleted calendar {calendar}" : "Jūs ištrynėte kalendorių {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atnaujino kalendorių {calendar}",
    "You updated calendar {calendar}" : "Jūs atnaujinote kalendorių {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} pradėjo bendrinti su jumis kalendorių {calendar}",
    "You shared calendar {calendar} with {user}" : "Jūs pradėjote bendrinti kalendorių {calendar} su {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} pradėjo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} nustojo bendrinti su jumis kalendorių {calendar}",
    "You unshared calendar {calendar} from {user}" : "Jūs nustojote bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} nustojo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} nustojo bendrinti su savimi kalendorių {calendar}",
    "You shared calendar {calendar} with group {group}" : "Jūs pradėjote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} pradėjo bendrinti kalendorių {calendar} su grupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Jūs nustojote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} nustojo bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} sukūrė įvykį {event}",
    "You created event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} sukūrėte įvykį {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ištrynė įvykį {event} iš kalendoriaus {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Jūs ištrynėte įvykį {event} iš kalendoriaus {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} atnaujino įvykį {event}",
    "You updated event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} atnaujinote įvykį {event}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} sąraše {calendar} sukūrė užduotį {todo}",
    "You created todo {todo} in list {calendar}" : "Jūs sąraše {calendar} sukūrėte užduotį {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} iš sąrašo {calendar} ištrynė užduotį {todo}",
    "You deleted todo {todo} from list {calendar}" : "Jūs iš sąrašo {calendar} ištrynėte užduotį {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} sąraše {calendar} atnaujino užduotį {todo}",
    "You updated todo {todo} in list {calendar}" : "Jūs sąraše {calendar} atnaujinote užduotį {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} sąraše {calendar} išsprendė užduotį {todo}",
    "You solved todo {todo} in list {calendar}" : "Jūs sąraše {calendar} išsprendėte užduotį {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} sąraše {calendar} vėl pradėjo užduotį {todo}",
    "You reopened todo {todo} in list {calendar}" : "Jūs sąraše {calendar} vėl pradėjote užduotį {todo}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendorius</strong> buvo pakeistas",
    "A calendar <strong>event</strong> was modified" : "Kalendoriaus <strong>įvykis</strong> buvo pakeistas",
    "A calendar <strong>todo</strong> was modified" : "Kalendoriaus <strong>užduotis</strong> buvo pakeista",
    "Contact birthdays" : "Kontaktų gimtadieniai",
    "Hello %s," : "Sveiki, %s,",
    "Invitation updated" : "Pakvietimas atnaujintas",
    "When:" : "Kada:",
    "Where:" : "Kur:",
    "Description:" : "Aprašas:",
    "Link:" : "Nuoroda:",
    "More options …" : "Daugiau parinkčių …",
    "Contacts" : "Kontaktai",
    "WebDAV" : "WebDAV",
    "Technical details" : "Techninė informacija",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Save" : "Įrašyti",
    "%s invited you to »%s«" : "%s pakvietė jus į »%s«",
    "CalDAV server" : "CalDAV serveris"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/lt_LT.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendorius",
    "Todos" : "Užduotys",
    "Personal" : "Asmeniniai",
    "{actor} created calendar {calendar}" : "{actor} sukūrė kalendorių {calendar}",
    "You created calendar {calendar}" : "Jūs sukūrėte kalendorių {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} ištrynė kalendorių {calendar}",
    "You deleted calendar {calendar}" : "Jūs ištrynėte kalendorių {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} atnaujino kalendorių {calendar}",
    "You updated calendar {calendar}" : "Jūs atnaujinote kalendorių {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} pradėjo bendrinti su jumis kalendorių {calendar}",
    "You shared calendar {calendar} with {user}" : "Jūs pradėjote bendrinti kalendorių {calendar} su {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} pradėjo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} nustojo bendrinti su jumis kalendorių {calendar}",
    "You unshared calendar {calendar} from {user}" : "Jūs nustojote bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} nustojo bendrinti kalendorių {calendar} su {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} nustojo bendrinti su savimi kalendorių {calendar}",
    "You shared calendar {calendar} with group {group}" : "Jūs pradėjote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} pradėjo bendrinti kalendorių {calendar} su grupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Jūs nustojote bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} nustojo bendrinti kalendorių {calendar} su grupe {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} sukūrė įvykį {event}",
    "You created event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} sukūrėte įvykį {event}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ištrynė įvykį {event} iš kalendoriaus {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Jūs ištrynėte įvykį {event} iš kalendoriaus {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} kalendoriuje {calendar} atnaujino įvykį {event}",
    "You updated event {event} in calendar {calendar}" : "Jūs kalendoriuje {calendar} atnaujinote įvykį {event}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} sąraše {calendar} sukūrė užduotį {todo}",
    "You created todo {todo} in list {calendar}" : "Jūs sąraše {calendar} sukūrėte užduotį {todo}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} iš sąrašo {calendar} ištrynė užduotį {todo}",
    "You deleted todo {todo} from list {calendar}" : "Jūs iš sąrašo {calendar} ištrynėte užduotį {todo}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} sąraše {calendar} atnaujino užduotį {todo}",
    "You updated todo {todo} in list {calendar}" : "Jūs sąraše {calendar} atnaujinote užduotį {todo}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} sąraše {calendar} išsprendė užduotį {todo}",
    "You solved todo {todo} in list {calendar}" : "Jūs sąraše {calendar} išsprendėte užduotį {todo}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} sąraše {calendar} vėl pradėjo užduotį {todo}",
    "You reopened todo {todo} in list {calendar}" : "Jūs sąraše {calendar} vėl pradėjote užduotį {todo}",
    "A <strong>calendar</strong> was modified" : "<strong>Kalendorius</strong> buvo pakeistas",
    "A calendar <strong>event</strong> was modified" : "Kalendoriaus <strong>įvykis</strong> buvo pakeistas",
    "A calendar <strong>todo</strong> was modified" : "Kalendoriaus <strong>užduotis</strong> buvo pakeista",
    "Contact birthdays" : "Kontaktų gimtadieniai",
    "%1$s via %2$s" : "%1$s per %2$s",
    "Hello %s," : "Sveiki, %s,",
    "Invitation updated" : "Pakvietimas atnaujintas",
    "%1$s invited you to »%2$s«" : "%1$s jus pakvietė į »%2$s«",
    "When:" : "Kada:",
    "Where:" : "Kur:",
    "Description:" : "Aprašas:",
    "Link:" : "Nuoroda:",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "More options …" : "Daugiau parinkčių …",
    "Contacts" : "Kontaktai",
    "WebDAV" : "WebDAV",
    "Technical details" : "Techninė informacija",
    "Remote Address: %s" : "Nuotolinis adresas: %s",
    "Request ID: %s" : "Užklausos ID: %s",
    "Are you accepting the invitation?" : "Ar priimate pakvietimą?",
    "Save" : "Įrašyti",
    "Calendar server" : "Kalendoriaus serveris",
    "%s via %s" : "%s per %s",
    "%s invited you to »%s«" : "%s pakvietė jus į »%s«",
    "CalDAV server" : "CalDAV serveris"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
